<?php
/*
Plugin Name: Yilick Ads
Description: Enable seamless integration of your Yilick classified ads into your WordPress website with the Yilick Ads plugin. Effortlessly showcase your listings to your audience, enhancing user engagement and maximizing exposure. Customizable and user-friendly, Yilick Ads empowers you to effortlessly display your classified ads across your WordPress site. Monetize your website while offering valuable content to your visitors with Yilick Ads!
Version: 1.0
Author: Yilick Inc
*/

// Add help menu on the plugin dashboard
add_action('admin_menu', 'yilick_ads_help_menu');
function yilick_ads_help_menu() {
    add_menu_page(
        'Yilick Ads Help', // Page title
        'Yilick Ads Help', // Menu title
        'manage_options', // Capability
        'yilick-ads-help', // Menu slug
        'yilick_ads_help_page', // Function
        'dashicons-info' // Icon
    );
}

// Help page content
function yilick_ads_help_page() {
    ?>
    <div class="wrap">
        <h1>Yilick Ads Help</h1>
        <p>Welcome to the Yilick Ads plugin! Follow the steps below to integrate the plugin and display ads using your Yilick account:</p>
        <ol>
            <li>Install and activate the Yilick Ads plugin on your WordPress website.</li>
            <li>Use the following shortcode to display ads on your website: <code>[yilick_ads email="email@example.com"]</code>. Replace <code>email@example.com</code> with the email associated with your Yilick account.</li>
            <li>Customize the ad display using CSS styles if necessary. You can add your CSS styles within the provided HTML section in the plugin file.</li>
        </ol>
        <p>If you encounter any issues or need further assistance, please contact support@yilick.com.</p>
    </div>
    <?php
}

// Shortcode to display ads with automatic pagination and loading progress
function display_ads($atts) {
    // Extract email attribute from shortcode attributes
    $atts = shortcode_atts(array(
        'email' => '', // Default value is an empty string
    ), $atts);

    // Retrieve email from shortcode attributes
    $email = $atts['email'];

    if (empty($email)) {
        return 'Error: Email not provided.';
    }

    // Format ads container with unique ID
    $ads_container_id = 'yilick-ads-container-' . uniqid();

    $ads_html = '<div id="' . esc_attr($ads_container_id) . '" class="ads-container"></div>';

    // Enqueue JavaScript to update ads container and fetch new ads
    add_action('wp_footer', function () use ($email, $ads_container_id) {
        ?>
        <script>
            jQuery(document).ready(function ($) {
                var page = 1; // Initial page number
                var fetchingAds = false; // Flag to prevent multiple simultaneous requests
                var noMoreAds = false; // Flag to indicate if there are no more ads to fetch

                // Function to fetch and update ads
                function updateAds() {
                    if (fetchingAds || noMoreAds) return; // Check if already fetching ads or there are no more ads
                    fetchingAds = true; // Set flag to true

                    // Display loading progress
                    $('#' + '<?php echo esc_js($ads_container_id); ?>').append('<div class="loading-progress">Loading...</div>');

                    // Create POST request to fetch ads with pagination parameters
                    $.ajax({
                        url: 'https://v2.yilick.ug/plugin-ads.php',
                        type: 'POST',
                        dataType: 'json',
                        data: {
                            email: '<?php echo esc_js($email); ?>',
                            page: page,
                        },
                        success: function (response) {
                            // Remove loading progress
                            $('#' + '<?php echo esc_js($ads_container_id); ?>').find('.loading-progress').remove();

                            if (response.length === 0) {
                                // No more ads to fetch
                                noMoreAds = true;
                                return;
                            }

                            // Append fetched ads to ads container
                            var adHtml = '<div class="row">';
                            $.each(response, function (index, ad) {
                                var modalId = 'adModal-' + page + '-' + index; // Generate unique modal ID
                                adHtml += '<div class="col-md-4 col-sm-6">';
                                adHtml += '<div class="ad" style="background-color: #fff; margin: 8px; border-radius: 10px; box-shadow: 0 0 15px rgba(0, 0, 0, 0.1); cursor: pointer;" data-toggle="modal" data-target="#' + modalId + '">';
                                adHtml += '<div style="height: 200px; overflow: hidden; border-top-left-radius: 10px; border-top-right-radius: 10px;">'; // Uniform height and cover photo
                                adHtml += '<img src="https://v2.yilick.ug/' + ad.photo + '" alt="' + ad.title + '" style="width: 100%; height: 100%; object-fit: cover; border-top-left-radius: 10px; border-top-right-radius: 10px;">';
                                adHtml += '</div>';
                                adHtml += '<div class="ad-details" style="padding: 15px;">';
                                adHtml += '<h3 style="margin: 0; font-size: 18px; line-height: 1.2; overflow: hidden; white-space: nowrap; text-overflow: ellipsis;">' + ad.title + '</h3>'; // One line title
                                adHtml += '<div class="row" style="margin-top: 10px;">';
                                adHtml += '<div class="col-6">';
                                adHtml += '<p class="ad-price" style="margin: 0; font-size: 16px; color: #28a745; font-weight: bold;">UGX ' + ad.price + '</p>'; // Green price
                                adHtml += '</div>';
                                adHtml += '<div class="col-6 text-right">';
                                adHtml += '<p class="ad-location" style="margin: 0; font-size: 16px; color: #666; font-style: italic;">' + ad.location + '</p>';
                                adHtml += '</div>';
                                adHtml += '</div>'; // Close row for price and location
                                adHtml += '<div class="row" style="margin-top: 15px;">';
                                adHtml += '<div class="col-6">';
                                adHtml += '<button class="btn-sm btn-outline-success btn-sm btn-block phone-number" data-phone="+256' + ad.phoneNumber + '" style="border-radius: 8px;"><i class="fas fa-phone-alt" style="margin-right: 5px;"></i> 0' + ad.phoneNumber + '</button>'; // Smaller phone number button
                                adHtml += '</div>';
                                adHtml += '<div class="col-6">';
                                adHtml += '<button class="btn-sm btn-success btn-sm btn-block whatsapp-message" data-whatsapp="+256' + ad.whatsappNumber + '" data-title="' + ad.title + '" data-price="' + ad.price.toLocaleString() + '" data-id="' + ad.id + '" data-uid="' + ad.uid + '" style="border-radius: 8px;"><i class="fab fa-whatsapp" style="margin-right: 5px;"></i> WhatsApp</button>'; // Smaller WhatsApp button
                                adHtml += '</div>';
                                adHtml += '</div>'; // Close row for buttons
                                adHtml += '</div>'; // Close ad-details div
                                adHtml += '</div>'; // Close ad div
                                adHtml += '</div>'; // Close col div
                                
                                // Modal for each ad
                                adHtml += '<div class="modal fade" id="' + modalId + '" tabindex="-1" role="dialog" aria-labelledby="adModalLabel' + index + '" aria-hidden="true">';
                                adHtml += '<div class="modal-dialog" role="document">';
                                adHtml += '<div class="modal-content">';
                                adHtml += '<div class="modal-header">';
                                adHtml += '<h5 class="modal-title" id="adModalLabel' + index + '">' + ad.title + '</h5>';
                                adHtml += '<button type="button" class="close" data-dismiss="modal" aria-label="Close">';
                                adHtml += '<span aria-hidden="true">&times;</span>';
                                adHtml += '</button>';
                                adHtml += '</div>';
                                adHtml += '<div class="modal-body">';
                                adHtml += '<img src="https://v2.yilick.ug/' + ad.photo + '" alt="' + ad.title + '" style="width: 100%; height: 400px; object-fit: contain">';
                                adHtml += '<p><strong>Price:</strong> UGX ' + ad.price + '</p>';
                                adHtml += '<p><strong>Location:</strong> ' + ad.location + '</p>';
                                adHtml += '<p><strong>Description:</strong> ' + ad.description + '</p>';
                                adHtml += '<p><strong>Ad Condition:</strong> ' + ad.adCondition + '</p>';
                                adHtml += '<p><strong>Category:</strong> ' + ad.category + '</p>';
                                adHtml += '<p><strong>Subcategory:</strong> ' + ad.subcategory + '</p>';
                                adHtml += '<p><strong>Price:</strong> UGX ' + ad.price + '</p>';
                                adHtml += '<p><strong>Location:</strong> ' + ad.location + '</p>';
                                adHtml += '</div>';
                                adHtml += '<div class="modal-footer">';
                                adHtml += '<button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>';
                                adHtml += '</div>';
                                adHtml += '</div>';
                                adHtml += '</div>';
                                adHtml += '</div>';
                            });
                            adHtml += '</div>'; // Close row div
                            $('#' + '<?php echo esc_js($ads_container_id); ?>').append(adHtml);
                            page++; // Increment page number
                            fetchingAds = false; // Reset flag to false
                        },
                        error: function () {
                            // Remove loading progress
                            $('#' + '<?php echo esc_js($ads_container_id); ?>').find('.loading-progress').remove();
                            $('#' + '<?php echo esc_js($ads_container_id); ?>').append('<div class="error">Error fetching ads</div>');
                            fetchingAds = false; // Reset flag to false
                        }
                    });
                }

                // Call updateAds function initially
                updateAds();

                // Automatically update ads when scrolling
                $(window).scroll(function () {
                    if ($(window).scrollTop() + $(window).height() >= $(document).height() - 100 && !fetchingAds) {
                        updateAds(); // Call updateAds function when user scrolls near bottom of page
                    }
                });

                // Open modal when ad is clicked
                $(document).on('click', '.ad', function () {
                    $(this).find('.modal').modal('show');
                });

                // Handle phone number button click
                $(document).on('click', '.phone-number', function (e) {
                    e.stopPropagation();
                    var phoneNumber = $(this).data('phone');
                    window.location.href = 'tel:' + phoneNumber; // Initiate phone call
                });

                // Handle WhatsApp button click
                $(document).on('click', '.whatsapp-message', function (e) {
                    e.stopPropagation();
                    var whatsappNumber = $(this).data('whatsapp');
                    var title = $(this).data('title');
                    var price = $(this).data('price');
                    var id = $(this).data('id');
                    var uid = $(this).data('uid');
                    var message = "Hi, I'm interested in " + title + " - UGX " + price + " which I found on Yilick app https://yilick.ug/share-product?id=" + id + "&sec=" + uid;
                    window.open('https://wa.me/' + whatsappNumber + '?text=' + encodeURIComponent(message), '_blank'); // Open WhatsApp chat
                });
            });
        </script>
        <?php
    });

    return $ads_html;
}
add_shortcode('yilick_ads', 'display_ads');
